<?php declare(strict_types = 0);
/*
** Glaber
** Copyright (C) 2001-2024 Glaber
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

namespace Widgets\ProblemHosts\Actions;

use APP, API,
	CArrayHelper,
	CControllerDashboardWidgetView,
	CControllerResponseData,
	CRoleHelper;

require_once APP::getRootDir().'/include/blocks.inc.php';

class WidgetView extends CControllerDashboardWidgetView {

	protected function doAction(): void {
		
		[$filter_groupids, $filter_hostids, $filter_severities] = \prepareProblemsCountersRequest($this->fields_values);

		[$groups, $hosts_data] = $this->fetchTriggerCountersByHostsAndGroupds($filter_groupids, $filter_hostids, $filter_severities);
		
		$this->setResponse(new CControllerResponseData([
			'name' => $this->getInput('name', $this->widget->getDefaultName()),
			'filter' => [
				'hostids' => $this->fields_values['hostids'],
				'severities' => $filter_severities,
				'hide_empty_groups' => $this->fields_values['hide_empty_groups'],
				'compact_counters' => $this->fields_values['compact_counters'],
			],
			'hosts_data' => $hosts_data,
			'groups' => $groups,
			'user' => [
				'debug_mode' => $this->getDebugMode()
			],
			'allowed_ui_problems' => $this->checkAccess(CRoleHelper::UI_MONITORING_PROBLEMS)
		]));
	}
	
	protected function fetchTriggerCountersByHostsAndGroupds(array &$filter_groupids = NULL , array &$filter_hostids = NULL, array &$filter_severities) {
	
		[$groups, $hosts] = expandGroupsHostsFromFilters($filter_groupids, $filter_hostids);
			
		foreach ($groups as $groupid => $group) {
			$groups[$groupid]['highest_severity'] = TRIGGER_SEVERITY_NOT_CLASSIFIED;
			$groups[$groupid]['hosts_total_count'] = 0;
			$groups[$groupid]['hosts_problematic_count'] = 0;
			$groups[$groupid]['hosts_problematic_list'] = [];
			$groups[$groupid]['problems']=[0, 0, 0, 0, 0, 0];
		}
	
		$trigger_states = \CZabbixServer::getHostTriggerCounters(\CSessionHelper::getId(), array_keys($hosts));
						
		foreach ($hosts as $host) {
			foreach ($host['hostgroups'] as $group) {
				if (array_key_exists($group['groupid'], $groups)) {
					$groups[$group['groupid']]['hosts_total_count']++;
				}
			}
		}
		
		$hosts_data = [];
		
		foreach ($trigger_states as $idx => $host_stat) {
		
			$hostid = $host_stat['hostid'];
			$host = $hosts[$hostid];
		
			if (isFilterdBySeverity($filter_severities, $host_stat['problems_by_severity'] ))
				continue;
					
			$hosts_data[$host['hostid']] = [
				'host' => $host['name'],
				'hostid' => $host['hostid'],
				'maintenanceid' => $host['maintenanceid'],
				'maintenance_status' => $host['maintenance_status'],
				'maintenance_type' => $host['maintenance_type'],
				'severities' => $host_stat['problems_by_severity']
			];
				
			foreach ($host['hostgroups'] as $group) {
				$groupid = $group['groupid'];
		
				if (!array_key_exists($groupid, $groups)) 
					continue;
					
				$total_problems = array_sum($host_stat['problems_by_severity']);
						
				if (0 < $total_problems) {
					$groups[$groupid]['hosts_problematic_list'][$host['hostid']]['name'] = $host['name'];
					$groups[$groupid]['hosts_problematic_count']++;
				}
						
				foreach ($filter_severities as $idx => $severity)  {
						
					$groups[$groupid]['problems'][$severity] += $host_stat['problems_by_severity'][$severity];
						
					if ( $host_stat['problems_by_severity'][$severity] > 0 && 
							 $severity > $groups[$groupid]['highest_severity'] )
						$groups[$groupid]['highest_severity'] = $severity;
		
				}	
			}
		}
		
		CArrayHelper::sort($groups, [['field' => 'name', 'order' => ZBX_SORT_UP]]);	

		return [$groups, $hosts_data];
	}
}
